fhirpack.load package — fhirpack 0.0.2b0 documentation

# fhirpack.load package

## Submodules

## fhirpack.load.base module

class fhirpack.load.base.BaseLoaderMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.load.base', 'sendResourcesToFiles': <function BaseLoaderMixin.sendResourcesToFiles>, 'sendBytesToFile': <function BaseLoaderMixin.sendBytesToFile>, 'sendToTable': <function BaseLoaderMixin.sendToTable>, 'sendDICOMToFiles': <function BaseLoaderMixin.sendDICOMToFiles>, '__dict__': <attribute '__dict__' of 'BaseLoaderMixin' objects>, '__weakref__': <attribute '__weakref__' of 'BaseLoaderMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __module__ = 'fhirpack.load.base'
  __weakref__

    list of weak references to the object (if defined)

  sendBytesToFile(input: Optional[list[bytearray]] = None, paths: Optional[list[str]] = None, guessExtension: bool = False, combine: bool = False, params: Optional[dict] = None)
  sendDICOMToFiles(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, combine: bool = False, params: Optional[dict] = None, ignoreFrame: bool = False)
  sendResourcesToFiles(paths: Optional[list[str]] = None, input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, combine: bool = False)
  sendToTable(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None, ignoreFrame: bool = False, fileType: str = 'csv', paths: Optional[list[str]] = None)

## fhirpack.load.condition module

class fhirpack.load.condition.LoaderConditionMixin

  Bases: `BaseLoaderMixin`

  __doc__ = None
  __module__ = 'fhirpack.load.condition'
  transformerConditionMethod()

## fhirpack.load.observation module

class fhirpack.load.observation.LoaderObservationMixin

  Bases: `BaseLoaderMixin`

  __doc__ = None
  __module__ = 'fhirpack.load.observation'
  transformerObservationMethod()

## fhirpack.load.patient module

class fhirpack.load.patient.LoaderPatientMixin

  Bases: `BaseLoaderMixin`

  __doc__ = None
  __module__ = 'fhirpack.load.patient'
  transformerPatientMethod()

## Module contents

class fhirpack.load.LoaderMixin

  Bases: `LoaderObservationMixin`, `LoaderPatientMixin`, `LoaderConditionMixin`

  __doc__ = None
  __module__ = 'fhirpack.load'